@@ -4,9 +4,10 @@ use strict;
 use DateTime;
 use DateTime::Set;
 
-our $VERSION = "0.13";
+our $VERSION = "0.14";
 
-RT->AddStyleSheets('calendar.css');
+RT->AddStyleSheets('calendar.css')
+    if RT->can('AddStyleSheets');
 
 sub FirstMonday {
     my ($year, $month) = (shift, shift);
